@@ -527,7 +527,7 @@ def daterange(date1, date2):
     for n in range(int((date2 - date1).days) + 1):
         yield date1 + timedelta(n)
 
-def correctPredictionsSingleDate(folder, dStr):
+def correctPredictionsSingleDate(folder, dStr, mode):
     dObj = datetime.datetime.strptime(dStr, "%Y-%m-%d")
 
     prev = dObj - datetime.timedelta(days=1)
@@ -622,8 +622,12 @@ def correctPredictionsSingleDate(folder, dStr):
 
     mask = (oriDF['HEADER_TIME_STAMP'] > currDateObj) & (oriDF['HEADER_TIME_STAMP'] < nextDateObj)
 
-    final_df = oriDF.loc[mask][
-        ['START_TIME', 'STOP_TIME', 'PREDICTED_SMOOTH', 'PROB_WEAR_SMOOTH', 'PROB_SLEEP_SMOOTH', 'PROB_NWEAR_SMOOTH']]
+    if mode == 'Yes':
+        final_df = oriDF.loc[mask]
+    else:
+        final_df = oriDF.loc[mask][
+            ['START_TIME', 'STOP_TIME', 'PREDICTED_SMOOTH', 'PROB_WEAR_SMOOTH', 'PROB_SLEEP_SMOOTH', 'PROB_NWEAR_SMOOTH']]
+
     final_df.rename(columns={'PREDICTED_SMOOTH':'PREDICTION'}, inplace=True)
     final_df['PREDICTION'].replace({0:'Wear',1:'Sleep',2:'Nonwear'}, inplace=True)
 
@@ -631,7 +635,7 @@ def correctPredictionsSingleDate(folder, dStr):
 
     final_df.to_csv(outPath, index=False, float_format='%.3f', compression='infer')
 
-def main(day_folder=None):
+def main(day_folder=None, debug='No'):
     if (day_folder is None):
         print("Must enter day folder path.")
         return
@@ -648,4 +652,4 @@ def main(day_folder=None):
         print("Second pass output file aleady exists.")
         return
 
-    correctPredictionsSingleDate(inFold,dateSt)
+    correctPredictionsSingleDate(inFold,dateSt,debug)
